@@ -127,7 +127,7 @@ class OneRegion(list):
 		if self.chrom not in boundaries_dict:
 			if action == "exit":
 				logger.error("Chromosome for region \"{0}\" is not found in list of available chromosomes ({1})".format(self, list(boundaries_dict.keys())))
-				sys.exit()
+				sys.exit(1)
 
 			self = None	#cannot cut to bounds when boundaries are not known; remove
 			return(self)
@@ -156,7 +156,7 @@ class OneRegion(list):
 				
 			elif action == "exit":
 				logger.error("Region \"{0}\" is outside of the chromosome boundaries ({1}: {2})".format(self, self.chrom, boundaries_dict[self.chrom]))
-				sys.exit()
+				sys.exit(1)
 
 		return(self)
 
@@ -223,7 +223,7 @@ class RegionList(list):
 			#Test line format
 			if re.match(r"[^\s]+\t\d+\t\d+\b.*", line) == None:
 				logger.error("Line {0} in {1} is not proper bed format:\n{2}".format(i+1, bedfile_f, line))
-				sys.exit()
+				sys.exit(1)
 
 			columns = line.split("\t") #split (and then .rstrip() afterwards)
 			columns[-1] = columns[-1].rstrip() # remove line-ending from last col
@@ -232,7 +232,7 @@ class RegionList(list):
 			
 			if columns[1] >= columns[2]:
 				logger.error("Start position is larger than end position in line {0} in {1}:\n{2}".format(i+1, bedfile_f, line))
-				sys.exit()
+				sys.exit(1)
 
 			region = OneRegion(columns)
 			self[i] = region
@@ -402,21 +402,22 @@ class RegionList(list):
 	def remove_duplicates(self):
 		""" Returns a unique list of sites """
 
-		self.loc_sort()
+		unique = deepcopy(self)
+		unique.loc_sort()
 		prev_chrom, prev_start, prev_end, prev_strand = "", 0, 0, ""
-		unique = RegionList()
 
-		for region in self:
+		for i, region in enumerate(unique):
 
 			curr_chrom, curr_start, curr_end, curr_strand = region.chrom, region.start, region.end, region.strand
 
 			if curr_chrom == prev_chrom and curr_start == prev_start and curr_end == prev_end and curr_strand == prev_strand:  #not unique
-				pass
-			else:
-				unique.append(region)
+				unique[i] = None
 
 			#Save as previous for next comparison
-			prev_chrom, prev_start, prev_end, prev_strand = region.chrom, region.start, region.end, region.strand
+			prev_chrom, prev_start, prev_end, prev_strand = curr_chrom, curr_start, curr_end, curr_strand
+
+		#Remove all None
+		unique = RegionList([region for region in unique if region is not None])
 
 		return(unique)
 
@@ -494,6 +495,7 @@ class RegionList(list):
 	def resolve_overlaps(self, priority="higher"):
 		""" Priority "higher" or "lower" """
 
+		self = deepcopy(self) #ensures that self is not changed
 		self.loc_sort()
 		no_regions = len(self)
 
@@ -532,10 +534,7 @@ class RegionList(list):
 					j = 1
 
 		#Remove all None
-		non_overlapping = RegionList()
-		for reg in self:
-			if reg != None:
-				non_overlapping.append(reg)
+		non_overlapping = RegionList([reg for reg in self if reg is not None])
 
 		return(non_overlapping)
 
