@@ -359,7 +359,7 @@ class Progress:
 def flatten_list(lst):
 
 	for element in lst:
-		if isinstance(element, collections.Iterable) and not isinstance(element, (str, bytes)):
+		if hasattr(element, "__iter__") and not isinstance(element, (str, bytes)):
 			yield from flatten_list(element)
 		else:
 			yield element
@@ -481,7 +481,7 @@ def match_lists(lofl): # list of lists
 			prefix = ""
 			suffix = ""
 
-		lofl[i] = [element.replace(prefix, "").replace(suffix, "") for element in lst]
+		lofl[i] = [re.sub("^" + prefix, "", re.sub(suffix + "$", "", element)) for element in lst]
 		prefixes.append(prefix)
 		suffixes.append(suffix)
 
